@@ -1,5 +1,5 @@
 ## function for obtaining predictions
-def get_predictions(GCS_DS_PATH, test_tfrec_path, BATCH_SIZE, model, output_filename):
+def get_predictions_tfrec(GCS_DS_PATH, test_tfrec_path, BATCH_SIZE, model, output_filename):
 	import numpy as np
 
 	testdata = get_test_dataset(GCS_DS_PATH, test_tfrec_path, BATCH_SIZE)
@@ -21,7 +21,7 @@ def get_predictions(GCS_DS_PATH, test_tfrec_path, BATCH_SIZE, model, output_file
 def get_predictions(testTFdataset, model, output_filename):
 	import numpy as np
 	images = testTFdataset.map(lambda image, idnum : image)
-	ids = testTFdataset.map(lambda image, idnum : idnum).unbatch()
+	test_ids = testTFdataset.map(lambda image, idnum : idnum).unbatch()
 
 	NUM_TEST_IMAGES = 0
 	for data in testTFdataset:
@@ -30,8 +30,8 @@ def get_predictions(testTFdataset, model, output_filename):
 	probabilities = model.predict(images)
 	predictions = np.argmax(probabilities, axis = 1)
 	print("Generating Output File..")
-	ids = next(iter(ids.batch(NUM_TEST_IMAGES))).numpy().astype('U')
-	np.savetxt(output_filename, np.rec.fromarrays([ids, predictions]), fmt = ['%s', '%d'], delimiter = ',', header = 'id,label', comments = '')
+	test_ids = next(iter(test_ids.batch(NUM_TEST_IMAGES))).numpy().astype('U')
+	np.savetxt(output_filename, np.rec.fromarrays([test_ids, predictions]), fmt=['%s', '%d'], delimiter=',', header='id,label', comments='')
 	print(f"predictions obtained with filename as -> {output_filename}")
 
 
